@@ -12,8 +12,8 @@ echo "ARCH = '$ARCH'"
 echo "PGBR_BUILD = '$PGBR_BUILD'"
 echo "PGBR_REPO_TYPE = '$PGBR_REPO_TYPE'"
 echo "PROFILE = '$PROFILE'"
-source profile.d/$PROFILE.profile
 source profile.d/vagrant.profile
+source profile.d/$PROFILE.profile
 
 if [ ! -z "$EXTRA" ]; then
     export EXTRA_VARS="$EXTRA_VARS $EXTRA"
@@ -28,17 +28,10 @@ if [ ! -z "$PGBR_REPO_TYPE" ]; then
     [ "$PGBR_REPO_TYPE" = "posix" ] && export EXTRA_VARS="$EXTRA_VARS pgbackrest_repo_path=/shared/repo1"
 fi
 
-[ ! -z "$edb_repository_username" ] && export EDB_REPO_USERNAME=$edb_repository_username
-[ ! -z "$edb_repository_password" ] && export EDB_REPO_PASSWORD=$edb_repository_password
 [ ! -z "$pgbackrest_git_url" ] && export EXTRA_VARS="$EXTRA_VARS pgbackrest_git_url=$pgbackrest_git_url"
 [ ! -z "$pgbackrest_git_branch" ] && export EXTRA_VARS="$EXTRA_VARS pgbackrest_git_branch=$pgbackrest_git_branch"
 
 echo "EXTRA_VARS = '$EXTRA_VARS'"
 echo "CLNAME=$CLNAME"
 
-if [ ! -z "$DBV" ]; then
-    export DBVERSION="$DBV"
-    echo "DBVERSION=$DBVERSION"
-fi
-
 sh ci.sh
